[llvm-commits] CVS: llvm/include/llvm/BasicBlock.h

Chris Lattner sabre at nondot.org
Fri Sep 22 21:04:00 PDT 2006



Changes in directory llvm/include/llvm:

BasicBlock.h updated: 1.59 -> 1.60
---
Log message:

add method, correct comment


---
Diffs of the changes:  (+7 -3)

 BasicBlock.h |   10 +++++++---
 1 files changed, 7 insertions(+), 3 deletions(-)


Index: llvm/include/llvm/BasicBlock.h
diff -u llvm/include/llvm/BasicBlock.h:1.59 llvm/include/llvm/BasicBlock.h:1.60
--- llvm/include/llvm/BasicBlock.h:1.59	Thu Jun  8 10:46:17 2006
+++ llvm/include/llvm/BasicBlock.h	Fri Sep 22 23:03:45 2006
@@ -109,10 +109,14 @@
   ///
   void eraseFromParent();
   
   /// moveBefore - Unlink this instruction from its current function and
   /// insert it into the function that MovePos lives in, right before
   /// MovePos.
   void moveBefore(BasicBlock *MovePos);
+  
+  /// moveAfter - Unlink this basic block from its current function and
+  /// insert it into the function that MovePos lives in, right after MovePos.
+  void moveAfter(BasicBlock *MovePos);
+  
 
   /// getSinglePredecessor - If this basic block has a single predecessor block,
   /// return the block, otherwise return a null pointer.
@@ -109,10 +109,14 @@
   void eraseFromParent();
   
-  /// moveBefore - Unlink this instruction from its current function and
-  /// insert it into the function that MovePos lives in, right before
-  /// MovePos.
+  /// moveBefore - Unlink this basic block from its current function and
+  /// insert it into the function that MovePos lives in, right before MovePos.
   void moveBefore(BasicBlock *MovePos);






More information about the llvm-commits mailing list